==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_COMMENT","kommentar");
define("_CONFIGURE","Indstillinger");
define("_LOGINCREATE","Log ind / Bliv bruger");
define("_THRESHOLD","Laveste score");
define("_NOCOMMENTS","Ingen kommentarer");
define("_NESTED","Indrykket");
define("_FLAT","I rkkeflge");
define("_THREAD","Trdet");
define("_OLDEST","ldste frst");
define("_NEWEST","Nyeste frst");
define("_HIGHEST","Hjeste score frst");
define("_COMMENTSWARNING","Alle kommentarer tilhrer indsenderen. Vi er ikke ansvarlige for indholdet og kan ikke tages som udtryk for vores synspunkter.");
define("_SCORE","Hits:");
define("_USERINFO","Brugerinfo");
define("_READREST","Ls resten af denne kommentar...");
define("_REPLY","Svar til denne");
define("_REPLYMAIN","Send kommentar");
define("_NOSUBJECT","Intet emne");
define("_NOANONCOMMENTS","Anonyme kan ikke skrive kommentarer. Vr venlig at <a href=\"modules.php?name=Your_Account\">oprette</a> dig som bruger.");
define("_PARENT","Forrige");
define("_ROOT","Rod");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ONN",", som skriver...");
define("_SUBJECT","Emne");
define("_SURVEYCOM","Skriv kommentar til afstemning");
define("_SURVEYCOMPRE","Gennemse din kommentar til afstemning");
define("_NOTRIGHT","Der er problemer med at analysere variablen i denne funktion. Denne besked er blot for at forhindre tingene i at blive forkludrede.");
define("_DIRECTCOM","Kommentar til afstemning...");
define("_SENDAMSG","Send en besked");
define("_PASTSURVEYS","Tidligere afstemninger");



define("_LVOTES","stemmer");
define("_TOTALVOTES","Antal stemmer:");
define("_VOTING","Stemmeboks");
define("_OTHERPOLLS","Andre afstemninger");
define("_CURRENTSURVEY","Nuvrende afstemning");
define("_CURRENTPOLLRESULTS","Nuvrende afstemningsresultater");
define("_PREVIEW","Gennemse");
define("_REFRESH","Genopfrisk");
define("_SURVEYS","Afstemninger");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_COMMENT","kommentar");
define("_CONFIGURE","Indstillinger");
define("_LOGINCREATE","Log ind / Bliv bruger");
define("_THRESHOLD","Laveste score");
define("_NOCOMMENTS","Ingen kommentarer");
define("_NESTED","Indrykket");
define("_FLAT","I rkkeflge");
define("_THREAD","Trdet");
define("_OLDEST","ldste frst");
define("_NEWEST","Nyeste frst");
define("_HIGHEST","Hjeste score frst");
define("_COMMENTSWARNING","Alle kommentarer tilhrer indsenderen. Vi er ikke ansvarlige for indholdet og kan ikke tages som udtryk for vores synspunkter.");
define("_SCORE","Hits:");
define("_USERINFO","Brugerinfo");
define("_READREST","Ls resten af denne kommentar...");
define("_REPLY","Svar til denne");
define("_REPLYMAIN","Send kommentar");
define("_NOSUBJECT","Intet emne");
define("_NOANONCOMMENTS","Anonyme kan ikke skrive kommentarer. Vr venlig at <a href=\"modules.php?name=Your_Account\">oprette</a> dig som bruger.");
define("_PARENT","Forrige");
define("_ROOT","Rod");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ONN",", som skriver...");
define("_SUBJECT","Emne");
define("_SURVEYCOM","Skriv kommentar til afstemning");
define("_SURVEYCOMPRE","Gennemse din kommentar til afstemning");
define("_NOTRIGHT","Der er problemer med at analysere variablen i denne funktion. Denne besked er blot for at forhindre tingene i at blive forkludrede.");
define("_DIRECTCOM","Kommentar til afstemning...");
define("_SENDAMSG","Send en besked");
define("_PASTSURVEYS","Tidligere afstemninger");



define("_LVOTES","stemmer");
define("_TOTALVOTES","Antal stemmer:");
define("_VOTING","Stemmeboks");
define("_OTHERPOLLS","Andre afstemninger");
define("_CURRENTSURVEY","Nuvrende afstemning");
define("_CURRENTPOLLRESULTS","Nuvrende afstemningsresultater");
define("_PREVIEW","Gennemse");
define("_REFRESH","Genopfrisk");
define("_SURVEYS","Afstemninger");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
